@@ -103,6 +103,9 @@ def main():
     gzip_type = args.compression
     auto = args.auto
 
+    # Set Nifti image extension from gzip type
+    nii_ext = ".nii" if 'n' in gzip_type else ".nii.gz"
+
     # Filename key flag dict - pass to organize
     key_flags = {
         'Part': args.complex,
@@ -211,7 +214,7 @@ def main():
         if no_sessions:
             dcm_dir_list = [src_subj_dir]
         else:
-            dcm_dir_list = glob(os.path.join(src_subj_dir, '*'))
+            dcm_dir_list = sorted(glob(os.path.join(src_subj_dir, '*')))
 
         # Loop over DICOM directories in subject directory
         for dcm_dir in dcm_dir_list:
@@ -263,9 +266,10 @@ def main():
 
                 # Compose command
                 cmd = ['dcm2niix',
-                       '-b', 'y',
+                       '-b', 'y',  # Create BIDS JSON sidecar
                        '-ba', anon,
                        '-z', gzip_type,
+                       '-w', '1',  # Overwrite existing files in work/
                        '-f', '%n--%d--%q--%s',
                        '-o', work_conv_dir,
                        dcm_dir]
@@ -282,16 +286,19 @@ def main():
                 btr.add_participant_record(dataset_dir, sid, dcm_info['Age'], dcm_info['Sex'])
 
             # Organize dcm2niix output into BIDS subject/session directories
-            d2n.organize_series(work_conv_dir,
-                            first_pass,
-                            translator,
-                            bids_ses_dir,
-                            sid,
-                            ses,
-                            key_flags,
-                            args.clean_conv_dir,
-                            overwrite,
-                            auto)
+            d2n.organize_series(
+                work_conv_dir,
+                first_pass,
+                translator,
+                bids_ses_dir,
+                sid,
+                ses,
+                key_flags,
+                nii_ext,
+                args.clean_conv_dir,
+                overwrite,
+                auto
+            )
 
     if first_pass:
 
@@ -313,7 +320,7 @@ def main():
             print('')
             print('Binding nearest fieldmap to each functional series')
             for bids_subj_dir in out_subj_dir_list:
-                fmaps.bind_fmaps(bids_subj_dir, no_sessions)
+                fmaps.bind_fmaps(bids_subj_dir, no_sessions, nii_ext)
 
     # Finally validate that all is well with the BIDS dataset
     if not first_pass:
